# Keys are ISO 3166-2:PL abbr.
VOIVODESHIPS = {
    "DS": {
        "teryt": "02",
        "name_pl": "dolnośląskie"
    },
    "KP": {
        "teryt": "04",
        "name_pl": "kujawsko-pomorskie"
    },
    "LU": {
        "teryt": "06",
        "name_pl": "lubelskie"
    },
    "LB": {
        "teryt": "08",
        "name_pl": "lubuskie"
    },
    "LD": {
        "teryt": "10",
        "name_pl": "łódzkie"
    },
    "MA": {
        "teryt": "12",
        "name_pl": "małopolskie"
    },
    "MZ": {
        "teryt": "14",
        "name_pl": "mazowieckie"
    },
    "OP": {
        "teryt": "16",
        "name_pl": "opolskie"
    },
    "PK": {
        "teryt": "18",
        "name_pl": "podkarpackie"
    },
    "PD": {
        "teryt": "20",
        "name_pl": "podlaskie"
    },
    "PM": {
        "teryt": "22",
        "name_pl": "pomorskie"
    },
    "SL": {
        "teryt": "24",
        "name_pl": "śląskie"
    },
    "SK": {
        "teryt": "26",
        "name_pl": "świętokrzyskie"
    },
    "WN": {
        "teryt": "28",
        "name_pl": "warmińsko-mazurskie"
    },
    "WP": {
        "teryt": "30",
        "name_pl": "wielkopolskie"
    },
    "ZP": {
        "teryt": "32",
        "name_pl": "zachodniopomorskie"
    },
}
